#
# spec file for package sdbootutil
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define nvr %{name}-%{version}-%{release}
%if 0%{?_build_in_place}
%define git_version %(git log '-n1' '--date=format:%Y%m%d' '--no-show-signature' "--pretty=format:+git%cd.%h")
BuildRequires:  git-core
%else
# this is required for obs' source validator. It's
# 20-files-present-and-referenced ignores all conditionals. So the
# definition of git_version actually happens always.
%define git_version %{nil}
%endif
Name:           sdbootutil
Version:        1+git20230814.38973c7%{git_version}
Release:        1.1
Summary:        script to install shim with sd-boot
License:        MIT
URL:            https://en.opensuse.org/openSUSE:Usr_merge
Source:         %{name}-%{version}.tar
Requires:       jq
Requires:       sed
Requires:       systemd-boot
Supplements:    (systemd-boot and shim)

%description
Hook scripts to install shim along with systemd-boot

%package snapper
Summary:        plugin script for snapper
Requires:       %{name} = %{version}
Requires:       btrfsprogs
Requires:       sdbootutil >= %{version}-%{release}
Requires:       snapper
Supplements:    (snapper and btrfsprogs and sdbootutil)

%description snapper
Plugin scripts for snapper to handle BLS config files

%package rpm-scriptlets
Summary:        dummy scriptlets for the kernel
# make sure to not replace scriptlets with nops on systems that
# use grub2
Conflicts:      grub2
Conflicts:      suse-kernel-rpm-scriptlets
Provides:       suse-kernel-rpm-scriptlets
Obsoletes:      %{name}-filetriggers < %{version}

%description rpm-scriptlets
Empty scriptlets to satisfy kernel dependencies

%prep
%setup -q

%build

%install
install -D -m 755 sdbootutil %{buildroot}%{_bindir}/sdbootutil

mkdir -p %{buildroot}%{_prefix}/lib/module-init-tools/kernel-scriptlets
for a in rpm; do
    install -m 755 "$a-script" %{buildroot}%{_prefix}/lib/module-init-tools/kernel-scriptlets
    for b in post posttrans postun pre preun; do
       ln -s "$a-script" %{buildroot}%{_prefix}/lib/module-init-tools/kernel-scriptlets/$a-$b
    done
done
for a in cert inkmp kmp; do
    for b in post posttrans postun pre preun; do
       ln -s /bin/true %{buildroot}%{_prefix}/lib/module-init-tools/kernel-scriptlets/$a-$b
    done
done

# snapper
install -d -m755 %{buildroot}%{_prefix}/lib/snapper/plugins
for i in 10-sdbootutil.snapper; do
  install -m 755 $i %{buildroot}%{_prefix}/lib/snapper/plugins/$i
done

%files
%license LICENSE
%{_bindir}/sdbootutil

%files rpm-scriptlets
%dir %{_prefix}/lib/module-init-tools
%{_prefix}/lib/module-init-tools/*

%files snapper
%dir %{_prefix}/lib/snapper
%dir %{_prefix}/lib/snapper/plugins
%{_prefix}/lib/snapper/plugins/*

%changelog
* Mon Aug 14 2023 lnussel@suse.com
- Update to version 1+git20230814.38973c7:
  * Support purge-kernels
  * Fix postun
  * Remove debug logging
* Mon Aug  7 2023 Fabian Vogt <fvogt@suse.com>
- Only install the snapper plugin if sdbootutil is requested
- Bypass git, owner is not available ATM
* Thu Jul 27 2023 lnussel@suse.com
- Update to version 1+git20230727.a0e666f:
  * Set and honor $SYSTEMD_ESP_PATH
  * rpm-script: don't remove kernel on reinstalls
* Wed Jul 26 2023 lnussel@suse.com
- Update to version 1+git20230726.a994d2e:
  * Fix installing extra kernels in MicroOS
  * Replace file triggers with scriptlet
  * Fix cleanup of rollback files
  * Don't install unchanged files
  * Add is-bootable and list-kernels commands
  * Add ARCHITECTURE.md which explains how the setup works
  * Add default loader config when installed
* Mon Jul 17 2023 lnussel@suse.com
- Update to version 1+git20230717.dac075e:
  * Install default boot loader in non-secure-boot case too
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.df6eaca:
  * Update features
  * Call stty only in interactive mode
  * silence stty errors
* Thu Jul 13 2023 lnussel@suse.de
- Update to version 1+git20230713.356f0c5:
  * Fix rpm dependencies
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230711.f5c7e48:
  * Fix setting root and rootflags
* Tue Jul 11 2023 lnussel@suse.com
- Update to version 1+git20230626.1ef6b4d:
  * creating /etc/kernel directory
  * Update help screen
* Thu Jun 15 2023 lnussel@suse.de
- Update to version 1+git20230615.587e134:
  * Handle out of space
* Thu Jun 15 2023 Ludwig Nussel <lnussel@suse.de>
- initial package
